<?php

$lang['404_head'] = 'ошибка 404';
$lang['404_body'] = '<p>
            Страница, не найдена. Перейдите, пожалуйста,<br/>
            на <a href="/">Главную</a> или проверьте правильность данных,<br/>
            введенных в адресную строку.
        </p>';