<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

/**
 * Description of RT_Model
 *
 * @author Igor Ratsun
 */
class RT_Model extends \Ciext\Model\AbstractEventModel
{
    
}
