<?php

$lang['404_head'] = 'Error 404';
$lang['404_body'] = '<p>
            Page not found. Go to<br/>
            <a href="/">Homepage</a>, or make sure that URL <br/>
            was written correctly.
        </p>';