<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

class Parser_include
{
    public function parse($view)
    {
        $ci = &get_instance();

        return $ci->ciext_parser->parse($ci->parser->parse($view, [], true));
    }
}