$(function () {
    $('.list-item .collapsed').click(function () {
        $(this).toggleClass('collapsed');
        $(this).parent().find('ul').toggleClass('collapse');
        return false;
    });
    $('#offcanvas-toggler').click(function () {
        var container = $('.layout-container');
        var width = 260;
        $('#left-menu').animate({
            'left': container.hasClass('sidebar-collapse') ? 0 : -width
        }, function () {
            container.toggleClass('sidebar-collapse');
            $('#offcanvas-toggler').parent().toggleClass('active');
        });
        container.find('.main-container, .header-container').animate({
            'margin-left': !container.hasClass('sidebar-collapse') ? 0 : width
        });
        return false;
    });
    // show active
    $('.list-item .collapse li.active').parent().parent().find('.collapsed').click();
});