<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

$config['upgrade_ciext'] = [
    [
        'version' => '0',
        'library' => 'ciext/migrations/ciext_upgrade_0',
    ],
    [
        'version' => '1.1.12',
        'library' => 'ciext/migrations/ciext_upgrade_1_1_12',
    ],
    [
        'version' => '1.1.13',
        'library' => 'ciext/migrations/ciext_upgrade_1_1_13',
    ],
    [
        'version' => '3.0.0',
        'library' => 'ciext/migrations/ciext_upgrade_3_0_0',
    ],
    [
        'version' => '3.0.1',
        'library' => 'ciext/migrations/ciext_upgrade_3_0_1',
    ],
    [
        'version' => '3.0.11',
        'library' => 'ciext/migrations/ciext_upgrade_3_0_11',
    ],
    [
        'version' => '3.0.12',
        'library' => 'ciext/migrations/ciext_upgrade_3_0_12',
    ],
    [
        'version' => '3.1.0',
        'library' => 'ciext/migrations/ciext_upgrade_3_1_0',
    ],
    [
        'version' => '3.1.1',
        'library' => 'ciext/migrations/ciext_upgrade_3_1_1',
    ],
    [
        'version' => '3.2.0',
        'library' => 'ciext/migrations/ciext_upgrade_3_2_0',
    ],
    [
        'version' => '3.2.3',
        'library' => 'ciext/migrations/ciext_upgrade_3_2_3',
    ],
    [
        'version' => '3.3.1',
        'library' => 'ciext/migrations/ciext_upgrade_3_3_1',
    ],
    [
        'version' => '3.3.3',
        'library' => 'ciext/migrations/ciext_upgrade_3_3_3',
    ],
];
